<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

class Paypal_install extends \Ciext\Controller\AbstractInstallController
{

    public function __construct()
    {
        parent::__construct();

        // Set acl module name
        $this->module_config['module_acl_name'] = 'paypal';

        // Set title
        $this->module_config['module_title'] = $this->lang->line('Paypal');
    }

    public function install($options = [])
    {
        return parent::install([
                    'shemaFile' => dirname(__DIR__) . '/data/install.sql',
        ]);
    }

    public function uninstall($options = [])
    {
        return parent::uninstall([
                    'dropTables' => [
                        'paypal',
                    ],
        ]);
    }

}
