<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

class Paypal_pages
{

    protected $ci;

    public function __construct()
    {
        $this->ci = get_instance();
        $this->ci->config->load('paypal/pages');
    }

    public function success($paypal_data = [])
    {
        return base_url($this->ci->config->item('paypal_success_page'));
    }

    public function cancel($paypal_data = [])
    {
        return base_url($this->ci->config->item('paypal_cancel_page'));
    }

}
