<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

$config['paypal_client_id'] = 'AYSq3RDGsmBLJE-otTkBtM-jBRd1TCQwFf9RGfwddNXWz0uFU9ztymylOhRS';
$config['paypal_client_secret'] = 'EGnHDxD_qRPdaLdZz8iCr8N7_MzF-YHPTkjs6NKYQvQSBngp4PTTVWkPZRbL';

$config['paypal_mode'] = 'sandbox';
